@@ -50,13 +50,15 @@ C<static method add : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarray
 
 Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs addition C<+> operation on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 sub
 
@@ -64,13 +66,15 @@ C<static method sub : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarray
 
 Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs subtraction C<-> operation on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 mul
 
@@ -78,27 +82,15 @@ C<static method mul : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarray
 
 Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs multiplication C<*> operation on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
-
-=head2 scamul
-
-C<static method scamul : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarray : L<R::NDArray::Double|SPVM::R::NDArray::Double>, $scalar_ndarray : L<R::NDArray::Double|SPVM::R::NDArray::Double>);>
-
-Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs multiplication C<*> operation on each element of the n-dimensional array $x_ndarray, and sets each element of the new n-dimensional array and the n-dimensional array $scalar_ndarray at data index 0 to the each operation result, and returns the new n-dimensional array.
-
-Exceptions:
-
-The n-dimensional array $scalar_ndarray must be defined. Otherwise, an exception is thrown.
-
-The n-dmension array $scalar_ndarray must be a L<scalar|SPVM::R::NDArray/"Scalar">.
-
-The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 div
 
@@ -106,27 +98,15 @@ C<static method div : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarray
 
 Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs division C</> operation on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
-
-=head2 scadiv
-
-C<static method scadiv : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarray : L<R::NDArray::Double|SPVM::R::NDArray::Double>, $scalar_ndarray : L<R::NDArray::Double|SPVM::R::NDArray::Double>);>
-
-Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs division C</> operations on the n-dimensional array $scalar_ndarray at data index 0 and each element of the n-dimensional array $x_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
-
-Exceptions:
-
-The n-dimensional array $scalar_ndarray must be defined. Otherwise, an exception is thrown.
-
-The n-dmension array $scalar_ndarray must be a L<scalar|SPVM::R::NDArray/"Scalar">.
-
-The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 neg
 
@@ -508,13 +488,15 @@ C<static method pow : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarray
 
 Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#pow|SPVM::Math/"pow"> method given each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 atan2
 
@@ -598,13 +580,15 @@ C<static method remainder : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_n
 
 Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#remainder|SPVM::Math/"remainder"> method on on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 fmod
 
@@ -612,13 +596,15 @@ C<static method fmod : L<R::NDArray::Double|SPVM::R::NDArray::Double> ($x_ndarra
 
 Creates a new L<R::NDArray::Double|SPVM::R::NDArray::Double> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#fmod|SPVM::Math/"fmod"> method on on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 sum
 
