@@ -54,13 +54,15 @@ C<static method add : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComple
 
 Creates a new L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#cadd|SPVM::Math/"cadd"> method on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 sub
 
@@ -68,13 +70,15 @@ C<static method sub : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComple
 
 Creates a new L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#csub|SPVM::Math/"csub"> method on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarrayy if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 mul
 
@@ -82,27 +86,15 @@ C<static method mul : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComple
 
 Creates a new L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#cmul|SPVM::Math/"cmul"> method on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
-
-=head2 scamul
-
-C<static method scamul : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> ($x_ndarray : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex>, $scalar_ndarray : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex>);>
-
-Creates a new L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#cmul|SPVM::Math/"cmul"> method on each element of the n-dimensional array $x_ndarray, and sets each element of the new n-dimensional array and the n-dimensional array $scalar_ndarray at data index 0 to the each operation result, and returns the new n-dimensional array.
-
-Exceptions:
-
-The n-dimensional array $scalar_ndarray must be defined. Otherwise, an exception is thrown.
-
-The n-dmension array $scalar_ndarray must be a L<scalar|SPVM::R::NDArray/"Scalar">.
-
-The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 div
 
@@ -110,27 +102,15 @@ C<static method div : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComple
 
 Creates a new L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#cdiv|SPVM::Math/"cdiv"> method on each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
-
-=head2 scadiv
-
-C<static method scadiv : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> ($x_ndarray : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex>, $scalar_ndarray : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex>);>
-
-Creates a new L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#cdiv|SPVM::Math/"cdiv"> method on the n-dimensional array $scalar_ndarray at data index 0 and each element of the n-dimensional array $x_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
-
-Exceptions:
-
-The n-dimensional array $scalar_ndarray must be defined. Otherwise, an exception is thrown.
-
-The n-dmension array $scalar_ndarray must be a L<scalar|SPVM::R::NDArray/"Scalar">.
-
-The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 neg
 
@@ -387,13 +367,15 @@ C<static method pow : L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComple
 
 Creates a new L<R::NDArray::DoubleComplex|SPVM::R::NDArray::DoubleComplex> object of the same dimensions as the n-dimensional array $x_ndarray for a return value, performs L<Math#cpow|SPVM::Math/"cpow"> method given each element of the n-dimensional array $x_ndarray and $y_ndarray, and sets each element of the new n-dimensional array to the each operation result, and returns the new n-dimensional array.
 
+$y_ndarray allows to be a L<scalar|SPVM::R::NDArray/"Scalar">. In that case, each element used in the operation is the element at index 0.
+
 Exceptions:
 
 The n-dimensional array $x_ndarray must be defined. Otherwise, an exception is thrown.
 
 The n-dimensional array $y_ndarray must be defined. Otherwise, an exception is thrown.
 
-The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray. Otherwise, an exception is thrown.
+The dimensions of $x_ndarray must be equal to the dimensions of $y_ndarray if $y_ndarray is not a scalar. Otherwise, an exception is thrown.
 
 =head2 sum
 
